@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2012 Shintaro Fujiwara 
+ * Copyright (C) 2007-2013 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,16 +61,16 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 
         fedoraVersionButtonGroup = new Q3ButtonGroup(this);
         fedoraVersionButtonGroup->resize( 150, 70 );
-        fourteenRadioButton = new QRadioButton(tr("version 14"), fedoraVersionButtonGroup);
-        fourteenRadioButton->setGeometry( 10, 10, 300, 20 );
         fifteenRadioButton = new QRadioButton(tr("version 15"), fedoraVersionButtonGroup);
-        fifteenRadioButton->setGeometry( 10, 30, 300, 20 );
+        fifteenRadioButton->setGeometry( 10, 10, 300, 20 );
         sixteenRadioButton = new QRadioButton(tr("version 16"), fedoraVersionButtonGroup);
-        sixteenRadioButton->setGeometry( 10, 50, 300, 20 );
+        sixteenRadioButton->setGeometry( 10, 30, 300, 20 );
         seventeenRadioButton = new QRadioButton(tr("version 17"), fedoraVersionButtonGroup);
-        seventeenRadioButton->setGeometry( 10, 70, 300, 20 );
+        seventeenRadioButton->setGeometry( 10, 50, 300, 20 );
+        eighteenRadioButton = new QRadioButton(tr("version 18"), fedoraVersionButtonGroup);
+        eighteenRadioButton->setGeometry( 10, 70, 300, 20 );
 
-	seventeenRadioButton->setChecked(true);
+	eighteenRadioButton->setChecked(true);
 
 	downloadButton = new QPushButton(tr("Download Fedora"), this);
 	downloadButton->setPaletteBackgroundColor(QColor(100,200,200));
@@ -125,9 +125,6 @@ void Downloader::download_button_clicked()
 		Q3Url url_for_fedora("ftp://mirrors.usc.edu");
 		url_for_fedora.setPort(21);
 		mirror = 1;
-		if(fourteenRadioButton->isChecked()){
-			version = "fourteen";
-		}
 		if(fifteenRadioButton->isChecked()){
 			version = "fifteen";
 		}
@@ -137,14 +134,14 @@ void Downloader::download_button_clicked()
 		if(seventeenRadioButton->isChecked()){
 			version = "seventeen";
 		}
+		if(eighteenRadioButton->isChecked()){
+			version = "eighteen";
+		}
 	}
 	if(jpRadioButton->isChecked()){
 		Q3Url url_for_fedora("ftp://ftp.riken.jp");
 		url_for_fedora.setPort(21);
 		mirror = 2;
-		if(fourteenRadioButton->isChecked()){
-			version = "fourteen";
-		}
 		if(fifteenRadioButton->isChecked()){
 			version = "fifteen";
 		}
@@ -154,14 +151,14 @@ void Downloader::download_button_clicked()
 		if(seventeenRadioButton->isChecked()){
 			version = "seventeen";
 		}
+		if(eighteenRadioButton->isChecked()){
+			version = "eighteen";
+		}
 	}
 	if(deRadioButton->isChecked()){
 		Q3Url url_for_fedora("ftp://ftp.uni-kl.de");
 		url_for_fedora.setPort(21);
 		mirror = 2;
-		if(fourteenRadioButton->isChecked()){
-			version = "fourteen";
-		}
 		if(fifteenRadioButton->isChecked()){
 			version = "fifteen";
 		}
@@ -171,14 +168,14 @@ void Downloader::download_button_clicked()
 		if(seventeenRadioButton->isChecked()){
 			version = "seventeen";
 		}
+		if(eighteenRadioButton->isChecked()){
+			version = "eighteen";
+		}
 	}
 	if(frRadioButton->isChecked()){
 		Q3Url url_for_fedora("ftp://ftp.lip6.fr");
 		url_for_fedora.setPort(21);
 		mirror = 2;
-		if(fourteenRadioButton->isChecked()){
-			version = "fourteen";
-		}
 		if(fifteenRadioButton->isChecked()){
 			version = "fifteen";
 		}
@@ -188,14 +185,14 @@ void Downloader::download_button_clicked()
 		if(seventeenRadioButton->isChecked()){
 			version = "seventeen";
 		}
+		if(eighteenRadioButton->isChecked()){
+			version = "eighteen";
+		}
 	}
 	if(auRadioButton->isChecked()){
 		Q3Url url_for_fedora("ftp://mirror.aarnet.edu.au");
 		url_for_fedora.setPort(21);
 		mirror = 2;
-		if(fourteenRadioButton->isChecked()){
-			version = "fourteen";
-		}
 		if(fifteenRadioButton->isChecked()){
 			version = "fifteen";
 		}
@@ -205,6 +202,9 @@ void Downloader::download_button_clicked()
 		if(seventeenRadioButton->isChecked()){
 			version = "seventeen";
 		}
+		if(eighteenRadioButton->isChecked()){
+			version = "eighteen";
+		}
 	}
 	downloader_process(url_for_fedora,version);
 }
@@ -221,7 +221,7 @@ void Downloader::downloader_process(const Q3Url &url_for_fedora, QString version
 	connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
 	process->start();
 	QMessageBox::warning(0, tr("Downloader Fedora"),
-				tr("Downloading Fedora in your home directory."));
+				tr("Downloading Fedora in /var/tmp directory."));
 }
 void Downloader::updateOutputTextEdit()
 {
@@ -241,7 +241,7 @@ void Downloader::processExited()
 		//textEdit1->append(tr("yum install process ended !"));
 		//textEdit1->append(tr("\n"));
 		QMessageBox::warning(0, tr("Downloader Fedora"),
-				     tr("Downloaded files are in your home directory."));
+				     tr("Downloaded files are in /var/tmp directory."));
 		return;
 	} else {
 		//textEdit1->append(tr("yum install process had an error !"));
